package cs108.observer;

public final class DiffCell extends Cell implements Observer {
	private final Cell c1, c2;
	private int diff;
	
	public DiffCell(String name, Cell c1, Cell c2) {
		super(name);
		this.c1 = c1;
		this.c2 = c2;
		this.diff = c1.value() - c2.value();
		
		c1.addObserver(this);
		c2.addObserver(this);
	}

	@Override
	public int value() {
		return diff;
	}
	
	@Override
	public void update(Subject s) {
		int newDiff = c1.value() - c2.value();
		if (newDiff != diff) {
			diff = newDiff;
			notifyObservers();
		}
	}
	
	@Override
	public String toString() {
		return String.format("%d [=%s-%s]", diff, c1.name(), c2.name());
	}
}
