package cs108.observer;

public final class SumCell extends Cell implements Observer {
	private final Cell c1, c2;
	private int sum;
	
	public SumCell(String name, Cell c1, Cell c2) {
		super(name);
		this.c1 = c1;
		this.c2 = c2;
		this.sum = c1.value() + c2.value();
		
		c1.addObserver(this);
		c2.addObserver(this);
	}

	@Override
	public int value() {
		return sum;
	}
	
	@Override
	public void update(Subject s) {
		int newSum = c1.value() + c2.value();
		if (newSum != sum) {
			sum = newSum;
			notifyObservers();
		}
	}
	
	@Override
	public String toString() {
		return String.format("%d [=%s+%s]", sum, c1.name(), c2.name());
	}
}
