package cs108.observer.gui;

import java.awt.Container;
import java.awt.GridLayout;
import java.util.Arrays;
import java.util.Iterator;
import java.util.List;

import javax.swing.JFormattedTextField;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.SwingConstants;

import cs108.observer.Cell;
import cs108.observer.ValueCell;

public final class Spreadsheet {
	private final List<Cell> cells;

	public Spreadsheet(List<Cell> cells) {
		this.cells = List.copyOf(cells);
	}

	public void createUI() {
        JFrame window = new JFrame();
        window.setTitle("Spreadsheet");
        window.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);

        Container contentPane = window.getContentPane();
		GridLayout layoutManager = new GridLayout(4, 4);
		layoutManager.setHgap(10);
		contentPane.setLayout(layoutManager);

		for (String l: Arrays.asList("", "A", "B", "C"))
			contentPane.add(new JLabel(l));
		Iterator<Cell> cellsIt = cells.iterator();
		for (int r = 1; r <= 3; ++r) {
			JLabel label = new JLabel(String.valueOf(r));
			label.setHorizontalAlignment(SwingConstants.RIGHT);
			contentPane.add(label);
			for (int c = 1; c <= 3; ++c) {
				Cell cell = cellsIt.next();
				if (cell instanceof ValueCell vCell) {
					JFormattedTextField textField = new JFormattedTextField(cell.value());
					textField.addActionListener(e -> vCell.setValue((Integer)textField.getValue()));
					contentPane.add(textField);
				} else {
					JLabel fLabel = new JLabel(cell.toString());
					cell.addObserver(s -> fLabel.setText(cell.toString()));
					contentPane.add(fLabel);
				}
			}
		}

        window.pack();
        window.setVisible(true);
	}
}
